@@ -10,29 +10,24 @@
 ESS <- function(x)
      {
      x <- as.matrix(x)
-     v0 <- order <- numeric(ncol(x))
+     v0 <- order <- rep(0, ncol(x))
      names(v0) <- names(order) <- colnames(x)
-     z <- 1:nrow(x)
-     for (i in 1:ncol(x))
-          {
+     N <- nrow(x)
+     z <- 1:N
+     for (i in 1:ncol(x)) {
           lm.out <- lm(x[, i] ~ z)
-          if(identical(all.equal(sd(residuals(lm.out)), 0), TRUE)) {
-               v0[i] <- 0
-               order[i] <- 0}
-          else {
+          if(!identical(all.equal(sd(residuals(lm.out)), 0), TRUE)) {
                ar.out <- try(ar(x[,i], aic=TRUE), silent=TRUE)
-               if(inherits(ar.out, "try-error")) {
-                    v0[i] <- 0
-                    order[i] <- 0}
-               else {
+               if(!inherits(ar.out, "try-error")) {
                     v0[i] <- ar.out$var.pred / {1 - sum(ar.out$ar)}^2
-                    order[i] <- ar.out$order}}
-          }
+                    order[i] <- ar.out$order}}}
      spec <- list(spec=v0, order=order)
      spec <- spec$spec
-     out <- ifelse(spec == 0, 0, nrow(x) * apply(x, 2, var)/spec)
-     out <- ifelse(out <= .Machine$double.eps, .Machine$double.eps, out)
-     out <- ifelse(out > nrow(x), nrow(x), out)
+     temp <- N * .colVars(x) / spec
+     out <- spec
+     out[which(spec != 0)] <- temp[which(spec != 0)]
+     out[which(out < .Machine$double.eps)] <- .Machine$double.eps
+     out[which(out > N)] <- N
      return(out)
      }
 
